################################################################################
## Library Imports
################################################################################

from extronlib import event, Version
from extronlib.device import ProcessorDevice, UIDevice
from extronlib.ui import Button, Label, Level
from extronlib.system import Wait, MESet, Timer

print(Version())

################################################################################
## User Imports
################################################################################

import bose_camera_VB1_v1_4_0_1 as BoseModule

################################################################################
## Processor Definition
################################################################################

MyProcessor  = ProcessorDevice('MyProcessor')

################################################################################
## UI Definition
################################################################################

MyPanel = UIDevice('MyPanel')

################################################################################
## Module Instantiation
################################################################################

MyModule = BoseModule.EthernetClass('192.168.196.111', 443, Model='VB1')
MyModule.devicePassword = 'Control97!'

################################################################################
## Constants / Global
################################################################################

BUTTON_STATES = ['Pressed', 'Released', 'Held', 'Repeated', 'Tapped']

################################################################################
## Button/Label Definitions
################################################################################

#-------------------------------------------------------------------------------
# Menu/Popups
#-------------------------------------------------------------------------------

btnMainMenu = [
  Button(MyPanel, 21),    # Camera
  Button(MyPanel, 22),    # Audio
  Button(MyPanel, 23),    # Monitoring
  Button(MyPanel, 24)     # Configuration
]

puMainMenuNames = [
  'Camera',
  'Audio',
  'Monitoring',
  'Configuration'
]

btnMainMenuME = MESet(btnMainMenu)

#-------------------------------------------------------------------------------
# Connection
#-------------------------------------------------------------------------------

btnConnect                              = Button(MyPanel, 1)
btnDisconnect                           = Button(MyPanel, 2)
btnReconnect                            = Button(MyPanel, 3)

btnConnected                            = Button(MyPanel, 11)

#-------------------------------------------------------------------------------
# Camera
#-------------------------------------------------------------------------------

btnCameraPresetHome                     = Button(MyPanel, 31, holdTime=2.0)
btnCameraPreset1                        = Button(MyPanel, 32, holdTime=2.0)
btnCameraPreset2                        = Button(MyPanel, 33, holdTime=2.0)

btnCameraTiltUp                         = Button(MyPanel, 41, holdTime=0.50, repeatTime=0.50)
btnCameraTiltDown                       = Button(MyPanel, 42, holdTime=0.50, repeatTime=0.50)
btnCameraPanLeft                        = Button(MyPanel, 43, holdTime=0.50, repeatTime=0.50)
btnCameraPanRight                       = Button(MyPanel, 44, holdTime=0.50, repeatTime=0.50)
btnCameraZoomIn                         = Button(MyPanel, 45, holdTime=0.50, repeatTime=0.50)
btnCameraZoomOut                        = Button(MyPanel, 46, holdTime=0.50, repeatTime=0.50)

btnCameraAutoFrameOn                    = Button(MyPanel, 51)
btnCameraAutoFrameOff                   = Button(MyPanel, 52)
btnCameraAutoFrameToggle                = Button(MyPanel, 53)

lvlCameraPan                            = Level(MyPanel, 61)
lvlCameraTilt                           = Level(MyPanel, 62)
lvlCameraZoom                           = Level(MyPanel, 63)

lvlCameraPan.SetRange(-10, 10)
lvlCameraTilt.SetRange(-10, 10)
lvlCameraZoom.SetRange(1, 10)

#-------------------------------------------------------------------------------
# Audio
#-------------------------------------------------------------------------------

btnAudioLoudspeakerUp                   = Button(MyPanel, 71, holdTime=0.50, repeatTime=0.50)
btnAudioLoudspeakerDown                 = Button(MyPanel, 72, holdTime=0.50, repeatTime=0.50)
btnAudioLoudspeakerMute                 = Button(MyPanel, 73)

lvlAudioLoudspeaker                     = Level(MyPanel, 81)

btnAudioMicrophoneMute                  = Button(MyPanel, 91)
btnAudioMicrophoneUnmute                = Button(MyPanel, 92)
btnAudioMicrophoneMuteToggle            = Button(MyPanel, 93)

btnAudioBluetoothPairOn                 = Button(MyPanel, 101)
btnAudioBluetoothPairOff                = Button(MyPanel, 102)
btnAudioBluetoothPairToggle             = Button(MyPanel, 103)

lvlAudioLoudspeaker.SetRange(0, 100)

#-------------------------------------------------------------------------------
# Configuration
#-------------------------------------------------------------------------------

btnConfigurationDeviceReady             = Button(MyPanel, 111)

btnConfigurationDeviceReboot            = Button(MyPanel, 121)

btnConfigurationSettingsHDMI            = Button(MyPanel, 131)

btnConfigurationSettingsBluetooth       = Button(MyPanel, 141)

btnConfigurationSettingsBluetoothButton = Button(MyPanel, 151)

#-------------------------------------------------------------------------------
# Monitoring
#-------------------------------------------------------------------------------

lblMonitoringDeviceName                 = Label(MyPanel, 161)
lblMonitoringDeviceSerial               = Label(MyPanel, 162)
lblMonitoringDeviceFW                   = Label(MyPanel, 163)
lblMonitoringDeviceCamera               = Label(MyPanel, 164)

lblMonitoringLocationBuilding           = Label(MyPanel, 171)
lblMonitoringLocationFloor              = Label(MyPanel, 172)
lblMonitoringLocationRoom               = Label(MyPanel, 173)

lblMonitoringEthernetState              = Label(MyPanel, 181)
lblMonitoringEthernetIP                 = Label(MyPanel, 182)
lblMonitoringEthernetMAC                = Label(MyPanel, 183)

lblMonitoringWifiState                  = Label(MyPanel, 191)
lblMonitoringWifiIP                     = Label(MyPanel, 192)
lblMonitoringWifiMAC                    = Label(MyPanel, 193)

btnMonitoringGPIMuteStatus              = Button(MyPanel, 201)

btnMonitoringUSBConnection              = Button(MyPanel, 211)
btnMonitoringUSBCallActive              = Button(MyPanel, 212)

btnMonitoringBluetoothConnection        = Button(MyPanel, 221)
btnMonitoringBluetoothStream            = Button(MyPanel, 222)

################################################################################
## Panel Events
################################################################################

#-------------------------------------------------------------------------------
# Menu/Popups
#-------------------------------------------------------------------------------

@event(btnMainMenu, BUTTON_STATES)
def OnMenuButtonPress(button, state):
  if state == 'Pressed':
    index = btnMainMenu.index(button)
    btnMainMenuME.SetCurrent(index)
    MyPanel.ShowPopup(puMainMenuNames[index])

#-------------------------------------------------------------------------------
# Connection
#-------------------------------------------------------------------------------

@event(btnConnect, BUTTON_STATES)
def OnConnectPress(button, state):
  if state == 'Pressed':
    MyModule.Connect()


@event(btnDisconnect, BUTTON_STATES)
def OnDisconnectPress(button, state):
  if state == 'Pressed':
    MyModule.Disconnect()


@event(btnReconnect, BUTTON_STATES)
def OnReconnectPress(button, state):
  if state == 'Pressed':
    MyModule.Disconnect()
    
    @Wait(5)
    def DoConnect():
      MyModule.Connect()

#-------------------------------------------------------------------------------
# Camera
#-------------------------------------------------------------------------------

@event(btnCameraPresetHome, BUTTON_STATES)
def OnCameraPresetHomePress(button, state):
  if state == 'Tapped':
    MyModule.Set('PresetRecall', 'Home')

  elif state == 'Held':
    MyModule.Set('PresetSave', 'Home')


@event(btnCameraPreset1, BUTTON_STATES)
def OnCameraPreset1Press(button, state):
  if state == 'Tapped':
    MyModule.Set('PresetRecall', 'Preset 1')

  elif state == 'Held':
    MyModule.Set('PresetSave', 'Preset 1')


@event(btnCameraPreset2, BUTTON_STATES)
def OnCameraPreset2Press(button, state):
  if state == 'Tapped':
    MyModule.Set('PresetRecall', 'Preset 2')

  elif state == 'Held':
    MyModule.Set('PresetSave', 'Preset 2')


@event(btnCameraTiltUp, BUTTON_STATES)
def OnCameraTiltUpPress(button, state):
  if state == 'Pressed' or state == 'Repeated':
    current = MyModule.ReadStatus('Tilt')

    if current is not None and current < 10:
      MyModule.Set('Tilt', current + 1)


@event(btnCameraTiltDown, BUTTON_STATES)
def OnCameraTiltDownPress(button, state):
  if state == 'Pressed' or state == 'Repeated':
    current = MyModule.ReadStatus('Tilt')

    if current is not None and current > -10:
      MyModule.Set('Tilt', current - 1)


@event(btnCameraPanLeft, BUTTON_STATES)
def OnCameraPanLeftPress(button, state):
  if state == 'Pressed' or state == 'Repeated':
    current = MyModule.ReadStatus('Pan')

    if current is not None and current > -10:
      MyModule.Set('Pan', current - 1)


@event(btnCameraPanRight, BUTTON_STATES)
def OnCameraPanRightPress(button, state):
  if state == 'Pressed' or state == 'Repeated':
    current = MyModule.ReadStatus('Pan')

    if current is not None and current < 10:
      MyModule.Set('Pan', current + 1)


@event(btnCameraZoomIn, BUTTON_STATES)
def OnCameraZoomInPress(button, state):
  if state == 'Pressed' or state == 'Repeated':
    current = MyModule.ReadStatus('Zoom')

    if current is not None and current < 10:
      MyModule.Set('Zoom', current + 1)


@event(btnCameraZoomOut, BUTTON_STATES)
def OnCameraZoomOutPress(button, state):
  if state == 'Pressed' or state == 'Repeated':
    current = MyModule.ReadStatus('Zoom')

    if current is not None and current > 1:
      MyModule.Set('Zoom', current - 1)


@event(btnCameraAutoFrameOn, BUTTON_STATES)
def OnCameraAutoFrameOnPress(button, state):
  if state == 'Pressed':
    MyModule.Set('Autoframing', 'On')


@event(btnCameraAutoFrameOff, BUTTON_STATES)
def OnCameraAutoFrameOffPress(button, state):
  if state == 'Pressed':
    MyModule.Set('Autoframing', 'Off')


@event(btnCameraAutoFrameToggle, BUTTON_STATES)
def OnCameraAutoFrameTogglePress(button, state):
  if state == 'Pressed':
    active = MyModule.ReadStatus('Autoframing')
    MyModule.Set('Autoframing', 'Off' if active == 'On' else 'On')

#-------------------------------------------------------------------------------
# Audio
#-------------------------------------------------------------------------------

@event(btnAudioLoudspeakerUp, BUTTON_STATES)
def OnAudioLoudspeakerUpPress(button, state):
  if state == 'Pressed' or state == 'Repeated':
    current = MyModule.ReadStatus('LoudspeakerVolume')
    
    if current is not None and current < 100:
      new = 100 if current + 3 > 100 else current + 3
      MyModule.Set('LoudspeakerVolume', new)


@event(btnAudioLoudspeakerDown, BUTTON_STATES)
def OnAudioLoudspeakerDownPress(button, state):
  if state == 'Pressed' or state == 'Repeated':
    current = MyModule.ReadStatus('LoudspeakerVolume')

    if current is not None and current > 0:
      new = 0 if current - 3 < 0 else current - 3
      MyModule.Set('LoudspeakerVolume', new)


@event(btnAudioLoudspeakerMute, BUTTON_STATES)
def OnAudioLoudspeakerMutePress(button, state):
  if state == 'Pressed':
    active = MyModule.ReadStatus('LoudspeakerMute')
    MyModule.Set('LoudspeakerMute', 'Off' if active == 'On' else 'On')


@event(btnAudioMicrophoneMute, BUTTON_STATES)
def OnAudioMicrophoneMutePress(button, state):
  if state == 'Pressed':
    MyModule.Set('MicrophoneMute', 'On')


@event(btnAudioMicrophoneUnmute, BUTTON_STATES)
def OnAudioMicrophoneUnmutePress(button, state):
  if state == 'Pressed':
    MyModule.Set('MicrophoneMute', 'Off')


@event(btnAudioMicrophoneMuteToggle, BUTTON_STATES)
def OnAudioMicrophoneMuteTogglePress(button, state):
  if state == 'Pressed':
    active = MyModule.ReadStatus('MicrophoneMute')
    MyModule.Set('MicrophoneMute', 'Off' if active == 'On' else 'On')


@event(btnAudioBluetoothPairOn, BUTTON_STATES)
def OnAudioBluetoothPairOnPress(button, state):
  if state == 'Pressed':
    MyModule.Set('BluetoothPairing', 'On')


@event(btnAudioBluetoothPairOff, BUTTON_STATES)
def OnAudioBluetoothPairOffPress(button, state):
  if state == 'Pressed':
    MyModule.Set('BluetoothPairing', 'Off')


@event(btnAudioBluetoothPairToggle, BUTTON_STATES)
def OnAudioBluetoothPairTogglePress(button, state):
  if state == 'Pressed':
    active = MyModule.ReadStatus('BluetoothPairing')
    MyModule.Set('BluetoothPairing', 'Off' if active == 'On' else 'On')

#-------------------------------------------------------------------------------
# Configuration
#-------------------------------------------------------------------------------

@event(btnConfigurationDeviceReboot, BUTTON_STATES)
def OnConfigurationDeviceRebootPress(button, state):
  if state == 'Pressed':
    MyModule.Set('Reboot', None)


@event(btnConfigurationSettingsHDMI, BUTTON_STATES)
def OnConfigurationSettingsHDMIPress(button, state):
  if state == 'Pressed':
    active = MyModule.ReadStatus('HDMIEnable')
    MyModule.Set('HDMIEnable', 'Off' if active == 'On' else 'On')


@event(btnConfigurationSettingsBluetooth, BUTTON_STATES)
def OnConfigurationSettingsBluetoothPress(button, state):
  if state == 'Pressed':
    active = MyModule.ReadStatus('Bluetooth')
    MyModule.Set('Bluetooth', 'Off' if active == 'On' else 'On')


@event(btnConfigurationSettingsBluetoothButton, BUTTON_STATES)
def OnConfigurationSettingsBluetoothButtonPress(button, state):
  if state == 'Pressed':
    active = MyModule.ReadStatus('BluetoothButton')
    MyModule.Set('BluetoothButton', 'Off' if active == 'On' else 'On')

################################################################################
## Module Status/Events
################################################################################

def StatusRegister():
  MyModule.SubscribeStatus('ConnectionStatus', None, OnConnectionStatusChange)
  MyModule.SubscribeStatus('Autoframing', None, OnAutoframingChange)
  MyModule.SubscribeStatus('Bluetooth', None, OnBluetoothChange)
  MyModule.SubscribeStatus('BluetoothButton', None, OnBluetoothButtonChange)
  MyModule.SubscribeStatus('BluetoothConnection', None, OnBluetoothConnectionChange)
  MyModule.SubscribeStatus('BluetoothPairing', None, OnBluetoothPairingChange)
  MyModule.SubscribeStatus('BluetoothStream', None, OnBluetoothStreamChange)
  MyModule.SubscribeStatus('LoudspeakerVolume', None, OnLoudspeakerVolumeChange)
  MyModule.SubscribeStatus('LoudspeakerMute', None, OnLoudspeakerMuteChange)
  MyModule.SubscribeStatus('MicrophoneMute', None, OnMicrophoneMuteChange)
  MyModule.SubscribeStatus('Pan', None, OnPanChange)
  MyModule.SubscribeStatus('SystemReady', None, OnSystemReadyChange)
  MyModule.SubscribeStatus('Tilt', None, OnTiltChange)
  MyModule.SubscribeStatus('Zoom', None, OnZoomChange)
  MyModule.SubscribeStatus('Building', None, OnBuildingChange)
  MyModule.SubscribeStatus('CameraState', None, OnCameraStateChange)
  MyModule.SubscribeStatus('EthernetMACAddress', None, OnEthernetMACAddressChange)
  MyModule.SubscribeStatus('EthernetState', None, OnEthernetStateChange)
  MyModule.SubscribeStatus('EthernetStaticIPAddress', None, OnEthernetStaticIPAddressChange)
  MyModule.SubscribeStatus('Floor', None, OnFloorChange)
  MyModule.SubscribeStatus('GPIMute', None, OnGPIMuteChange)
  MyModule.SubscribeStatus('HDMIEnable', None, OnHDMIEnableChange)
  MyModule.SubscribeStatus('Room', None, OnRoomChange)
  MyModule.SubscribeStatus('SystemFirmwareVersion', None, OnSystemFirmwareVersionChange)
  MyModule.SubscribeStatus('SystemName', None, OnSystemNameChange)
  MyModule.SubscribeStatus('SystemReady', None, OnSystemReadyChange)
  MyModule.SubscribeStatus('SystemSerialNumber', None, OnSystemSerialNumberChange)
  MyModule.SubscribeStatus('USBCallStatus', None, OnUSBCallStatusChange)
  MyModule.SubscribeStatus('USBConnection', None, OnUSBConnectionChange)
  MyModule.SubscribeStatus('WiFiMACAddress', None, OnWiFiMACAddressChange)
  MyModule.SubscribeStatus('WiFiState', None, OnWiFiStateChange)
  MyModule.SubscribeStatus('WiFiStaticIPAddress', None, OnWiFiStaticIPAddressChange)
  
  @Wait(5)
  def DoUpdate():
    MyModule.Update('Autoframing')  
    MyModule.Update('Bluetooth')
    MyModule.Update('BluetoothButton')
    MyModule.Update('BluetoothConnection')
    MyModule.Update('BluetoothPairing')
    MyModule.Update('BluetoothStream')
    MyModule.Update('LoudspeakerVolume')
    MyModule.Update('LoudspeakerMute')
    MyModule.Update('MicrophoneMute')
    MyModule.Update('Pan')
    MyModule.Update('SystemReady')
    MyModule.Update('Tilt')
    MyModule.Update('Zoom')
    MyModule.Update('Building')
    MyModule.Update('CameraState')
    MyModule.Update('EthernetMACAddress')
    MyModule.Update('EthernetState')
    MyModule.Update('EthernetStaticIPAddress')
    MyModule.Update('Floor')
    MyModule.Update('GPIMute')
    MyModule.Update('HDMIEnable')
    MyModule.Update('Room')
    MyModule.Update('SystemFirmwareVersion')
    MyModule.Update('SystemName')
    MyModule.Update('SystemReady')
    MyModule.Update('SystemSerialNumber')
    MyModule.Update('USBCallStatus')
    MyModule.Update('USBConnection')
    MyModule.Update('WiFiMACAddress')
    MyModule.Update('WiFiState')
    MyModule.Update('WiFiStaticIPAddress')
    
    
def OnAutoframingChange(command, value, qualifier):
  print('OnAutoframingChange.{0}[{1}]'.format(command, value, qualifier))

  btnCameraAutoFrameOn.SetState(value == 'On')
  btnCameraAutoFrameOff.SetState(value == 'Off')


def OnBluetoothChange(command, value, qualifier):
  print('OnBluetoothChange.{0}[{1}]'.format(command, value, qualifier))

  btnConfigurationSettingsBluetooth.SetState(value == 'On')


def OnBluetoothButtonChange(command, value, qualifier):
  print('OnBluetoothButtonChange.{0}[{1}]'.format(command, value, qualifier))

  btnConfigurationSettingsBluetoothButton.SetState(value == 'On')


def OnBluetoothConnectionChange(command, value, qualifier):
  print('OnBluetoothConnectionChange.{0}[{1}]'.format(command, value, qualifier))

  btnMonitoringBluetoothConnection.SetState(value == 'Connected')


def OnBluetoothPairingChange(command, value, qualifier):
  print('OnBluetoothPairingChange.{0}[{1}]'.format(command, value, qualifier))

  btnAudioBluetoothPairOn.SetState(value == 'On')
  btnAudioBluetoothPairOff.SetState(value == 'Off')


def OnBluetoothStreamChange(command, value, qualifier):
  print('OnBluetoothStreamChange.{0}[{1}]'.format(command, value, qualifier))

  btnMonitoringBluetoothStream.SetState(value == 'Active')


def OnConnectionStatusChange(command, value, qualifier):
  print('OnConnectionStatusChange.{0}[{1}]'.format(command, value, qualifier))

  btnConnected.SetState(value == 'Connected')


def OnLoudspeakerVolumeChange(command, value, qualifier):
  print('OnLoudspeakerVolumeChange.{0}[{1}]'.format(command, value, qualifier))

  lvlAudioLoudspeaker.SetLevel(int(value))


def OnLoudspeakerMuteChange(command, value, qualifier):
  print('OnLoudspeakerMuteChange.{0}[{1}]'.format(command, value, qualifier))

  btnAudioLoudspeakerMute.SetState(value == 'On')


def OnMicrophoneMuteChange(command, value, qualifier):
  print('OnMicrophoneMuteChange.{0}[{1}]'.format(command, value, qualifier))

  btnAudioMicrophoneMute.SetState(value == 'On')
  btnAudioMicrophoneUnmute.SetState(value == 'Off')


def OnPanChange(command, value, qualifier):
  print('OnPanChange.{0}[{1}]'.format(command, value, qualifier))

  lvlCameraPan.SetLevel(int(value))


def OnSystemReadyChange(command, value, qualifier):
  print('OnSystemReadyChange.{0}[{1}]'.format(command, value, qualifier))

  btnConfigurationDeviceReady.SetState(value == 'Ready')


def OnTiltChange(command, value, qualifier):
  print('OnTiltChange.{0}[{1}]'.format(command, value, qualifier))  

  lvlCameraTilt.SetLevel(int(value))


def OnZoomChange(command, value, qualifier):
  print('OnZoomChange.{0}[{1}]'.format(command, value, qualifier))  

  lvlCameraZoom.SetLevel(int(value))
  

def OnBuildingChange(command, value, qualifier):
  print('OnBuildingChange.{0}[{1}]'.format(command, value, qualifier))  

  lblMonitoringLocationBuilding.SetText(value)


def OnCameraStateChange(command, value, qualifier):
  print('OnCameraStateChange.{0}[{1}]'.format(command, value, qualifier))  

  lblMonitoringDeviceCamera.SetText(value)
  

def OnEthernetMACAddressChange(command, value, qualifier):
  print('OnEthernetMACAddressChange.{0}[{1}]'.format(command, value, qualifier))  

  lblMonitoringEthernetMAC.SetText(value)


def OnEthernetStateChange(command, value, qualifier):
  print('OnEthernetStateChange.{0}[{1}]'.format(command, value, qualifier))  

  lblMonitoringEthernetState.SetText(value)


def OnEthernetStaticIPAddressChange(command, value, qualifier):
  print('OnEthernetStaticIPAddressChange.{0}[{1}]'.format(command, value, qualifier))  

  lblMonitoringEthernetIP.SetText(value)


def OnFloorChange(command, value, qualifier):
  print('OnFloorChange.{0}[{1}]'.format(command, value, qualifier))  

  lblMonitoringLocationFloor.SetText(value)


def OnGPIMuteChange(command, value, qualifier):
  print('OnGPIMuteChange.{0}[{1}]'.format(command, value, qualifier))  

  btnMonitoringGPIMuteStatus.SetState(value == 'On')


def OnHDMIEnableChange(command, value, qualifier):
  print('OnHDMIEnableChange.{0}[{1}]'.format(command, value, qualifier))  

  btnConfigurationSettingsHDMI.SetState(value == 'On')


def OnRoomChange(command, value, qualifier):
  print('OnRoomChange.{0}[{1}]'.format(command, value, qualifier))  

  lblMonitoringLocationRoom.SetText(value)


def OnSystemFirmwareVersionChange(command, value, qualifier):
  print('OnSystemFirmwareVersionChange.{0}[{1}]'.format(command, value, qualifier))  

  lblMonitoringDeviceFW.SetText(value)


def OnSystemNameChange(command, value, qualifier):
  print('OnSystemNameChange.{0}[{1}]'.format(command, value, qualifier))  

  lblMonitoringDeviceName.SetText(value)


def OnSystemSerialNumberChange(command, value, qualifier):
  print('OnSystemSerialNumberChange.{0}[{1}]'.format(command, value, qualifier))  

  lblMonitoringDeviceSerial.SetText(value)


def OnUSBCallStatusChange(command, value, qualifier):
  print('OnUSBCallStatusChange.{0}[{1}]'.format(command, value, qualifier))  

  btnMonitoringUSBCallActive.SetState(value == 'Active')


def OnUSBConnectionChange(command, value, qualifier):
  print('OnUSBConnectionChange.{0}[{1}]'.format(command, value, qualifier))  

  btnMonitoringUSBConnection.SetState(value == 'Connected')


def OnWiFiMACAddressChange(command, value, qualifier):
  print('OnWiFiMACAddressChange.{0}[{1}]'.format(command, value, qualifier))  

  lblMonitoringWifiMAC.SetText(value)


def OnWiFiStateChange(command, value, qualifier):
  print('OnWiFiStateChange.{0}[{1}]'.format(command, value, qualifier))  

  lblMonitoringWifiState.SetText(value)


def OnWiFiStaticIPAddressChange(command, value, qualifier):
  print('OnWiFiStaticIPAddressChange.{0}[{1}]'.format(command, value, qualifier))  

  lblMonitoringWifiIP.SetText(value)

################################################################################
## Module Polling
################################################################################

def StartPollTimer():
  global POLL_TIMER
  global POLL_TIME
  
  if POLL_TIMER is None:
    POLL_TIMER = Wait(POLL_TIME, PollTimerEvent)


def StopPollTimer():        
  global POLL_TIMER
  
  if POLL_TIMER is not None:
    POLL_TIMER.Cancel()
    POLL_TIMER = None


def RestartPollTimer():
  StopPollTimer()
  StartPollTimer()


def PollTimerEvent(): 
  MyModule.Update('Autoframing')  
  MyModule.Update('Bluetooth')
  MyModule.Update('BluetoothButton')
  MyModule.Update('BluetoothConnection')
  MyModule.Update('BluetoothPairing')
  MyModule.Update('BluetoothStream')
  MyModule.Update('LoudspeakerVolume')
  MyModule.Update('LoudspeakerMute')
  MyModule.Update('MicrophoneMute')
  MyModule.Update('Pan')
  MyModule.Update('SystemReady')
  MyModule.Update('Tilt')
  MyModule.Update('Zoom')
  MyModule.Update('Building')
  MyModule.Update('CameraState')
  MyModule.Update('EthernetMACAddress')
  MyModule.Update('EthernetState')
  MyModule.Update('EthernetStaticIPAddress')
  MyModule.Update('Floor')
  MyModule.Update('GPIMute')
  MyModule.Update('HDMIEnable')
  MyModule.Update('Room')
  MyModule.Update('SystemFirmwareVersion')
  MyModule.Update('SystemName')
  MyModule.Update('SystemReady')
  MyModule.Update('SystemSerialNumber')
  MyModule.Update('USBCallStatus')
  MyModule.Update('USBConnection')
  MyModule.Update('WiFiMACAddress')
  MyModule.Update('WiFiState')
  MyModule.Update('WiFiStaticIPAddress')
  
  RestartPollTimer()

################################################################################
## Module Connection
################################################################################

@event(MyModule, ['Connected', 'Disconnected'])
def OnDeviceConnectionChange(interface, state):    
  print('OnDeviceConnectionChange.{0}.{1}'.format(interface.Hostname, state))
  
  if state == 'Connected':
    StatusRegister()
     
  elif state == 'Disconnected':
    ResetUI()
    

################################################################################
## Reset UI
################################################################################

def ResetUI():
  btnConnected.SetState(False)

  btnCameraAutoFrameOn.SetState(False)
  btnCameraAutoFrameOff.SetState(True)

  lvlCameraPan.SetLevel(-10)
  lvlCameraTilt.SetLevel(-10)
  lvlCameraZoom.SetLevel(1)

  btnAudioLoudspeakerMute.SetState(False)
  lvlAudioLoudspeaker.SetLevel(0)

  btnAudioMicrophoneMute.SetState(False)
  btnAudioMicrophoneUnmute.SetState(True)

  btnAudioBluetoothPairOn.SetState(False)
  btnAudioBluetoothPairOff.SetState(True)

  btnConfigurationDeviceReady.SetState(False)

  btnConfigurationSettingsHDMI.SetState(False)
  btnConfigurationSettingsBluetooth.SetState(False)
  btnConfigurationSettingsBluetoothButton.SetState(False)

  lblMonitoringDeviceName.SetText('')
  lblMonitoringDeviceSerial.SetText('')
  lblMonitoringDeviceFW.SetText('')
  lblMonitoringDeviceCamera.SetText('')

  lblMonitoringLocationBuilding.SetText('')
  lblMonitoringLocationFloor.SetText('')
  lblMonitoringLocationRoom.SetText('')

  lblMonitoringEthernetState.SetText('')
  lblMonitoringEthernetIP.SetText('')
  lblMonitoringEthernetMAC.SetText('')

  lblMonitoringWifiState.SetText('')
  lblMonitoringWifiIP.SetText('')
  lblMonitoringWifiMAC.SetText('')

  btnMonitoringGPIMuteStatus.SetState(False)

  btnMonitoringUSBConnection.SetState(False)
  btnMonitoringUSBCallActive.SetState(False)

  btnMonitoringBluetoothConnection.SetState(False)
  btnMonitoringBluetoothStream.SetState(False)

  btnMainMenuME.SetCurrent(0)
  MyPanel.ShowPopup(puMainMenuNames[0])

################################################################################
## Initialize
################################################################################

def Initialize():
  ResetUI()
  MyModule.Connect()

################################################################################
## Main
################################################################################

Initialize()